@@ -49,16 +49,18 @@ static void expand_or_collapse_selected_rows (const gpointer action_pointer);
 static void create_cm_headline (      GtkWidget *context_menu, 
                                 const gchar     *headline_txt)
 {
-    GtkWidget *headline_label = gtk_label_new (headline_txt);
+    g_autofree gchar *adjusted_headline_txt = g_strdup_printf ("- %s", headline_txt);
+    GtkWidget *headline_label = gtk_label_new (adjusted_headline_txt);
     GtkWidget *menu_item = gtk_menu_item_new ();
 
     g_object_set (menu_item, "sensitive", FALSE, NULL);
 
     gtk_label_set_xalign (GTK_LABEL (headline_label), 0.0);
     gtk_style_context_add_class (gtk_widget_get_style_context (headline_label), "cm_class");
-    gtk_css_provider_load_from_data (ks.cm_css_provider, ".cm_class { color: #ffffff; background-color: #66669b; }", -1, NULL);
+    gtk_css_provider_load_from_data (ks.cm_css_provider, ".cm_class { font-weight: bold; color: #ffffff; background-color: #444444; }", -1, NULL);
     gtk_style_context_add_provider (gtk_widget_get_style_context (headline_label), 
                                     GTK_STYLE_PROVIDER (ks.cm_css_provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    gtk_style_context_add_class (gtk_widget_get_style_context (headline_label), "box_class");
     gtk_container_add (GTK_CONTAINER (menu_item), headline_label);
     gtk_menu_shell_append (GTK_MENU_SHELL (context_menu), menu_item);
 }
